# ![Shellodoro](https://user-images.githubusercontent.com/83695097/189335921-4c7514f0-fbfe-4387-9597-fa4a09c03561.jpg)

# Right in your favorite terminal

Now you do not have to be distracted from the terminal. Just work with pomodoro in terminal!

## Elementary usage

Ready to use right after installation. Just run with one simple command. _And nothing more..._

## Multifunctional & Customizable

Elementary, but **powerful** tool.

Supports various timers - classic, 90/30, 52/17. And also your **custom timers!**

![work](https://user-images.githubusercontent.com/83695097/189348014-ccd0c123-4e94-4fb6-a92e-a709431a02f5.gif)

If you forgot modes names, list they with one simple command

![Screenshot_20220909_151609](https://user-images.githubusercontent.com/83695097/189348625-7a5226c9-f094-4a35-a7c8-ed705c936b82.png)

Shellodoro automaticaly save your ~~personal data~~ statistics. Look at it **directly from the terminal.**

![Screenshot_20220909_152241](https://user-images.githubusercontent.com/83695097/189349010-94f96031-80b6-4eb5-b553-8fa2622e3d5f.png)

Also shellodoro sends notifications, when pomodoro ends

![Screenshot_20220909_152432](https://user-images.githubusercontent.com/83695097/189349699-138e6300-4482-47c1-b3ab-19b56e233279.png)

![Screenshot_20220909_152656](https://user-images.githubusercontent.com/83695097/189349675-eb96b31d-4111-470b-bb83-eb305c5eb167.png)

# Installation

```
pip install shellodoro
```

Then, run in terminal

```
shdr --help
```

Congratulations!

# Contribution

If you like that repository, please star it ⭐

The project is completely open for contributions! Make pull requests and submit issues.
